#
# spec file for package fd
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fd
Version:        8.3.0
Release:        bp154.1.27
Summary:        An alternative to the "find" utility
License:        Apache-2.0 AND MIT
Group:          Productivity/File utilities
URL:            https://github.com/sharkdp/fd
Source:         https://github.com/sharkdp/fd/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        cargo_config
BuildRequires:  cargo-packaging

%description
fd is an alternative to GNU find. It features:

* Colorized terminal output (similar to ls).
* The search is case-insensitive by default. It switches to
  case-sensitive if the pattern contains an uppercase character.
* By default, ignores patterns from .gitignore, and ignores hidden
  directories and files.
* Supports regular expressions and Unicode awareness.
* A parallel execution similar to GNU Parallel is available.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       bash-completion
Supplements:    (%{name} and bash)
BuildArch:      noarch

%description bash-completion
The official bash completion script for fd, generated during the build.

%package zsh-completion
Summary:        ZSH Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
The official zsh completion script for fd, generated during the build.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
The official fish completion script for fd, generated during the build.

%prep
%autosetup -a1
mkdir .cargo
cp %{SOURCE2} .cargo/config

%build
%{cargo_build}

%install
%{cargo_install}

# install shell completions and man page
install -Dm644 target/release/build/fd-find-*/out/fd.bash %{buildroot}%{_datadir}/bash-completion/completions/fd
install -Dm644 target/release/build/fd-find-*/out/fd.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/fd.fish
install -Dm644 contrib/completion/_fd %{buildroot}%{_datadir}/zsh/site-functions/_fd
install -Dm644 doc/fd.1 %{buildroot}%{_mandir}/man1/fd.1

%files
%license LICENSE-MIT LICENSE-APACHE
%doc README.md
%{_bindir}/fd
%{_mandir}/man1/fd.1%{?ext_man}

%files bash-completion
%{_datadir}/bash-completion

%files fish-completion
%{_datadir}/fish

%files zsh-completion
%{_datadir}/zsh

%changelog
* Mon Nov 29 2021 sebix+novell.com@sebix.at
- Update to version 8.3.0:
  * Update usage section
  * Bump version
  * Update CHANGELOG for v8.3
  * Update dependencies
  * Use non-sync channel
  * squash! Add buffering to stdout when it's not a terminal
  * Add entry for buffering to CHANGELOG
  * Add buffering to stdout when it's not a terminal
  * Modify example to a realistic use case
  * Add an example of the -X option using rg
* Tue Sep 28 2021 William Brown <william.brown@suse.com>
- Replace rust-packaging with cargo-packaging
* Sat Dec 26 2020 Avindra Goolcharan <avindra@opensuse.org>
- Replace manual vendoring, build and install with rust-packaging macros
* Fri Dec 25 2020 Wang Jun <jgwang@suse.com>
- Update to 8.2.1
  * No functional changes with respect to v8.2.0. Bugfix in the release process.
- Update to 8.2.0
  * Features
  - Add new `--prune` flag, see #535 (@reima)
  - Improved the usability of the time-based options, see #624 and #645 (@gorogoroumaru)
  - Add support for exact file sizes in the `--size` filter, see #669 and #696 (@Rogach)
  - `fd` now prints an error message if the search pattern requires a leading dot but
    `--hidden` is not enabled (Unix only), see #615
  * Bugfixes
  - Avoid panic when performing limited searches in directories with restricted permissions, see #678
  - Invalid numeric command-line arguments are silently ignored, see #675
  - Disable jemalloc on Android, see #662
  - The `--help` text will be colorless if `NO_COLOR` has been set, see #600 (@xanonid)
  * Changes
  - If `LS_COLORS` is not set (e.g. on Windows), we now provide a more comprehensive default which
    includes much more filetypes, see #604 and #682 (mjsir911).
  * Other
  - Added `zsh` completion files, see #654 and #189 (@smancill)
* Tue Jul 28 2020 Martin Rey <mrey@suse.com>
- Update to 8.1.1
  * Bugfixes
  - Support colored output on older Windows versions if either
    (1) --color=always is set or
    (2) the TERM environment variable is set. See #469
* Wed May 20 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 8.1.0
  * Features
  - Add new --owner [user][:group] command-line option
  - Add support for a global ignore file (~/.config/fd/ignore on Unix)
  - Do not exit immediately if one of the search paths is missing
  * Bugfixes
  - Reverted a change from fd 8.0 that enabled colors on all
    Windows terminals (see below) in order to support
    older Windows versions again
  - Fix --glob behavior with empty pattern
* Thu Apr 16 2020 Martin Rey <mrey@suse.com>
- Update to 8.0.0
  * Features
  - Add a new -l/--list-details option to show more details about
    the search results.
  - Add a new --max-results=<count> option to limit the number of
    search results, see #472, #476 and #555
  - Add the alias -1 for --max-results=1, see #561.
  - Add new --type socket and --type pipe filters, see #511.
  - Add new --min-depth <depth> and --exact-depth <depth> options
    in addition to the existing option to limit the maximum
    depth. See #404.
  - Support additional ANSI font styles in LS_COLORS: faint, slow
    blink, rapid blink, dimmed, hidden and strikethrough.
  * Bugfixes
  - Preserve non-UTF8 filenames: invalid UTF-8 filenames are now
    properly passed to child-processes when using --exec,
  - -exec-batch or --list-details. In fd's output, we replace
    non-UTF-8 sequences with the "�" character. However, if the
    output of fd goes to another process, we print the actual
    bytes of the filename. For more details, see #558 and #295.
  - LS_COLORS entries with unsupported font styles are not
    completely ignored, see #552
  * Changes
  - When using --glob in combination with --full-path, a *
    character does not match a path separation character (/ or
    \\) anymore. You can use ** for that. This allows things like
    fd -p -g '/some/base/path/*/*/*.txt' which would previously
    match to arbitrary depths (instead of exactly two folders
    below /some/base/path. See #404.
  - "Legacy" support to use fd -exec (with a single dash) has
    been removed. Use fd -x or fd --exec instead.
  - Overall improved error handling and error messages.
  * Other
  - Korean translation of the README, see: 한국어
- Changes from 7.5.0
  * Features
  - Added --one-file-system (aliases: --mount, --xdev) to not
    cross file system boundaries on Unix and Windows, see #507
  - Added --base-directory to change the working directory in
    which fd is run, see #509 and #475
  - fd will not use colored output if the NO_COLOR environment
    variable is set, see #550 and #551
  - fd --exec will return exit code 1 if one of the executed
    commands fails, see #526 and #531
  * Bug Fixes
  - Fixed 'command not found' error when using zsh completion,
    see #487
  - fd -L should include broken symlinks, see #357 and #497
  - Display directories even if we don't have permission to
    enter, see #437
  * Changes
  - A flag can now be passed multiple times without producing an
    error, see #488 and #496
  - Search results are sorted when using the -X option to match
    the behaviour of piping to xargs, see #441 and #524
* Sun Mar 15 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 7.4.0
  * Added a new --path-separator <sep> option
  * When fd is run with the --exec-batch/-X option, it now exposes
    the exit status of the command that was run
  * Added a new -g/--glob option to switch to glob-based searches
  * Use jemalloc by default, improving the performance for almost all searches
  * Reduce number of stat syscalls, improving the performance for searches
    where file metadata is required
  * Added support for filtering by file modification time by adding
    two new options --changed-before <date|duration> and --changed-within <..>.
    For more details, see the --help text, the man page,
    the relevant issue #165 and the PR #339 (@kimsnj)
  * Added --show-errors option to enable the display of filesystem error messages
    such as "permission denied", see #311 (@psinghal20 and @majecty)
  * Added --maxdepth as a (hidden) alias for --max-depth, see #323 (@mqudsi)
  * Added --search-path option which can be supplied to replace
    the positional path argument at any position.
  * New --exec-batch <cmd>/-X <cmd> option for batch execution of commands
  * Support for 24-bit color codes
* Sun Sep 16 2018 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 7.1.0
  Features
  * Added --size filter option
  * Added --type empty (or -t e) to search for empty files and/or directories
  Changes
  * .gitignore files will only be respected in Git repositories, not outside.
  * A few performance improvements for --type searches
- cleanup with spec-cleaner
* Mon Mar 26 2018 avindra@opensuse.org
- Update to version 7.0.0
  Features
  * Added --type executable (or -t x) to search for executable
    files only
  * Added support for .fdignore files
  * Added --ignore-file option to add custom ignore files
  * Suggest --fixed-strings on invalid regular expressions
  * Detect when user supplied path instead of pattern
  Changes
  * .ignore and .rgignore files are not parsed anymore. Use
    .fdignore files
  * or add custom files via --ignore-file instead.
  Bugfixes
  * Properly normalize absolute paths
  * Invalid utf8 filenames displayed when -e is used
  * If --type is used, fifos/sockets/etc. are always shown
- cleanup with spec-cleaner
* Sun Mar 18 2018 jengelh@inai.de
- Ensure neutrality of description. Describe the feature
  differences to GNU find.
* Tue Mar 13 2018 avindra@opensuse.org
- ship man page and shell completions
  - reduce size of tarballs
  - neutralize description a bit
  - port history to fd.changes
* Sat Mar 10 2018 viktor.saevars@gmail.com
- Updated to version 6.3.0
* Sun Oct  8 2017 viktor.saevars@gmail.com
- Initial packaging  @ 4.0.0
